# python-lib

open api python lib for plugin

- `pipenv install requests`

Update related image and lib

- [Agent Dockerfile](https://github.com/FlowCI/flow-agent-x/blob/master/Dockerfile)
- [Pyenv Dockerfile](https://github.com/FlowCI/images/blob/master/pyenv/Dockerfile)
- [Plugin runtime Dockerfile](https://github.com/FlowCI/images/blob/master/plugin-runtime/Dockerfile)
